import { useState } from 'react';
import BarcodeScannerComponent from 'react-qr-barcode-scanner';
import { Container, Row, Col } from 'react-bootstrap';
import Table from 'react-bootstrap/Table';
import Alert from 'react-bootstrap/Alert';

import './App.css';
import 'bootstrap/dist/css/bootstrap.min.css';

function App() {
    const [reqAccount, setReqAccount] = useState('');
    const [actAccount, setActAccount] = useState('');
    const [balance, setBalance] = useState(-1);
    const [statusMsg, setStatusMsg] = useState('');
    const [msgType, setMsgType] = useState('info');
    
    const handleScan = async (err, result) => {
	if (result) {
	    const ra = result.text;
	    setReqAccount(ra);
	    setStatusMsg('Loading');
	    setMsgType('primary');
	    try {
		const resp = await fetch('/api/barcode/' + ra);
		if (resp.ok) {
		    const json = await resp.json();
		    setActAccount(ra);
		    setBalance(json.amount);
		    setStatusMsg('OK');
		    setMsgType('success');
		}
	    } catch(ex) {
		setMsgType('danger');
		setStatusMsg(ex.message);
	    }
	}
    };

    return (
	<Container>
	    <Row>
		<Col>
		    <BarcodeScannerComponent
			width={"100%"}
			height={"auto"}
			onUpdate={handleScan}
			delay={1500}
		    />
		</Col>
	    </Row>
	    <Row>
		<Col>
		    <Table>
			<tr>
			    <th>Requested:</th>
			    <td>{reqAccount}</td>
			</tr>
			<tr>
			    <th>Loaded:</th>
			    <td>{actAccount}</td>
			</tr>
			<tr>
			    <th>Balance:</th>
			    <td>{balance}</td>
			</tr>
		    </Table>
		</Col>
	    </Row>
	    <Row>
		<Col>
		    <Alert variant={msgType}>{statusMsg}</Alert>
		</Col>
	    </Row>
	</Container>
    );
}

export default App;
